@@ -278,7 +278,7 @@ editor_show_grid_settings_dialog (GtkWidget *widget)
   GSList *group;
   GtkWidget *transient_parent;
 
-  dialog = gtk_window_new (GTK_WINDOW_DIALOG);
+  dialog = gtk_window_new (GTK_WINDOW_TOPLEVEL);
   gtk_window_set_title (GTK_WINDOW (dialog), _("Grid Options"));
   gtk_window_set_position (GTK_WINDOW (dialog), GTK_WIN_POS_MOUSE);
   gtk_window_set_wmclass (GTK_WINDOW (dialog), "grid_options", "Glade");
@@ -450,7 +450,7 @@ editor_show_snap_settings_dialog (GtkWidget *widget)
   GtkWidget *dialog, *vbox, *table, *label, *button, *hbbox, *separator;
   GtkWidget *transient_parent;
 
-  dialog = gtk_window_new (GTK_WINDOW_DIALOG);
+  dialog = gtk_window_new (GTK_WINDOW_TOPLEVEL);
   gtk_window_set_title (GTK_WINDOW (dialog), _("Snap Options"));
   gtk_window_set_position (GTK_WINDOW (dialog), GTK_WIN_POS_MOUSE);
   gtk_window_set_wmclass (GTK_WINDOW (dialog), "snap_options", "Glade");
@@ -718,7 +718,7 @@ placeholder_finish_replace (GtkWidget * new_widget, GbWidgetNewData * data)
 	  if (!gb_widget_replace_child (data->parent, data->current_child,
 					scrolledwin))
 	    {
-	      glade_util_show_message_box (_("Couldn't insert a GtkScrolledWindow widget."));
+	      glade_util_show_message_box (_("Couldn't insert a GtkScrolledWindow widget."), data->parent);
 	      gtk_widget_destroy (scrolledwin);
 	      gtk_widget_destroy (new_widget);
 	      return;
@@ -753,7 +753,7 @@ placeholder_finish_replace (GtkWidget * new_widget, GbWidgetNewData * data)
       if (!gb_widget_replace_child (data->parent, data->current_child,
 				    viewport))
 	{
-	  glade_util_show_message_box (_("Couldn't insert a GtkViewport widget."));
+	  glade_util_show_message_box (_("Couldn't insert a GtkViewport widget."), data->parent);
 	  gtk_widget_destroy (viewport);
 	  gtk_widget_destroy (new_widget);
 	  return;
@@ -780,7 +780,8 @@ placeholder_finish_replace (GtkWidget * new_widget, GbWidgetNewData * data)
     }
   else
     {
-      glade_util_show_message_box (_("Couldn't add new widget."));
+      glade_util_show_message_box (_("Couldn't add new widget."),
+				   data->parent);
 
       /* I think we can safely destroy the new widget. */
       gtk_widget_destroy (new_widget);
@@ -1128,7 +1129,7 @@ editor_on_button_press (GtkWidget * signal_widget,
 					    "\n"
 					    "Tip: GTK+ uses containers to lay out widgets.\n"
 					    "Try deleting the existing widget and using\n"
-					    "a box or table container instead.\n"));
+					    "a box or table container instead.\n"), widget);
              already_shown = TRUE;
            }
         }
@@ -2623,7 +2624,7 @@ editor_refresh_widget_area (GtkWidget * widget, gint x, gint y, gint w, gint h)
 static void
 clear_child_windows (GdkWindow * window, gint x, gint y, gint w, gint h)
 {
-  GList *children;
+  GList *children, *orig_children;
   GdkWindow *child_window;
   gint win_x, win_y, win_w, win_h;
 #ifndef _WIN32
@@ -2640,7 +2641,7 @@ clear_child_windows (GdkWindow * window, gint x, gint y, gint w, gint h)
   area.width = w;
   area.height = h;
 
-  children = gdk_window_get_children (window);
+  orig_children = children = gdk_window_get_children (window);
   while (children)
     {
       child_window = children->data;
@@ -2677,7 +2678,7 @@ clear_child_windows (GdkWindow * window, gint x, gint y, gint w, gint h)
 	}
       children = children->next;
     }
-  g_list_free (children);
+  g_list_free (orig_children);
 }
 
 
@@ -3027,7 +3028,7 @@ editor_delete_widget (GtkWidget * widget)
   error = editor_can_delete_widget (widget);
   if (error)
     {
-      glade_util_show_message_box (error);
+      glade_util_show_message_box (error, widget);
       return;
     }
 
@@ -3131,7 +3132,7 @@ editor_delete_widget (GtkWidget * widget)
     }
   else
     {
-      glade_util_show_message_box (_("Couldn't delete widget."));
+      glade_util_show_message_box (_("Couldn't delete widget."), widget);
       gtk_object_sink (GTK_OBJECT (placeholder));
       gtk_widget_unref (placeholder);
     }
