@@ -26,6 +26,8 @@
 
 #include "glade.h"
 #include "styles.h"
+#include "glade_widget_data.h"
+#include "gbsource.h"
 
 #ifdef __cplusplus
 extern "C" {
@@ -53,84 +55,6 @@ extern const gchar *GladeMenuItemStockIndexKey;
 extern const gchar *GladeMenuItemIconKey;
 
 
-/*************************************************************************
- * Extra data kept for each widget.
- *************************************************************************/
-
-/* Flags in GbWidgetData */
-enum
-{
-  GB_VISIBLE		= 1 << 0, /* If the widget is initially visible */
-  GB_SENSITIVE		= 1 << 1, /* If the widget is initially sensitive */
-  GB_GRAB_DEFAULT	= 1 << 2, /* If it grabs the default */
-  GB_GRAB_FOCUS		= 1 << 3, /* If it grabs the focus */
-  GB_STYLE_IS_UNNAMED	= 1 << 4, /* If it's using its own unnamed style */
-  GB_STYLE_PROPAGATE	= 1 << 5, /* If it propgates style to its children */
-  GB_ACTIVE		= 1 << 6, /* If it is initially active (for toggles) */
-  GB_X_SET		= 1 << 7, /* If the x pos is set explicitly */
-  GB_Y_SET		= 1 << 8, /* If the y pos is set explicitly */
-  GB_WIDTH_SET		= 1 << 9, /* If the width is set explicitly */
-  GB_HEIGHT_SET		= 1 << 10,/* If the height is set explicitly */
-
-  GB_SIZE_NOT_ALLOCATED	= 1 << 11 /* Internally used so that a widget's size
-				     and position properties aren't displayed
-				     until its area has been allocated. */
-};
-
-typedef struct _GbWidgetData  GbWidgetData;
-struct _GbWidgetData
-{
-  guint16	 flags;
-  gint16	 x;
-  gint16	 y;
-  gint16	 width;
-  gint16	 height;
-  gint		 events;
-  gchar		*tooltip;
-  GList		*signals;
-  GList		*accelerators;
-#ifdef GLADE_STYLE_SUPPORT
-  GbStyle	*gbstyle;
-#endif
-
-  /* C options. */
-  gchar		*source_file;
-  guint		 public_field : 1;
-
-  /* C++ options. */
-  guint		 cxx_separate_file : 1;
-  guint		 cxx_use_heap : 1;
-  guint		 cxx_separate_class : 1;
-  guint		 cxx_visibility : 2; 
-
-  /* 0=private 1=protected 2=public */
-  GbWidget      *gbwidget;
-};
-
-typedef struct _GbSignal GbSignal;
-struct _GbSignal
-{
-  gchar		*name;
-  gchar		*handler;
-  gchar		*object;
-  gboolean	 after;
-  gchar		*data;
-  /* This records the last time that handler, object or data were changed,
-     since we have to change the prototype output when they change.
-     name can't be changed, or it would become a completely different signal */
-  time_t	 last_modification_time;
-};
-
-typedef struct _GbAccelerator GbAccelerator;
-struct _GbAccelerator
-{
-  guint8	 modifiers;
-  gchar		*key;
-  gchar		*signal;
-};
-
-
-
 /*************************************************************************
  * Data structures passed to the GbWidget functions
  *************************************************************************/
@@ -144,8 +68,6 @@ typedef struct _GbWidgetSetArgData		GbWidgetSetArgData;
 typedef struct _GbWidgetCreateMenuData		GbWidgetCreateMenuData;
 typedef struct _GbWidgetDestroyData		GbWidgetDestroyData;
 
-#include "gbsource.h"
-
 typedef void (*GbWidgetNewCallback)	(GtkWidget *widget,
 					 GbWidgetNewData *data);
 
@@ -186,7 +108,7 @@ struct _GbWidgetNewData
   GtkWidget	*parent;
   GtkWidget	*current_child;
   gint		 x, y;
-  GbWidgetData	*widget_data;
+  GladeWidgetData *widget_data;
 
   /* This is only used when loading. */
   GbWidgetSetArgData *loading_data;
@@ -215,7 +137,7 @@ struct _GbWidgetGetArgData
   GladeProject  *project;
   GbWidgetAction action;		/* GB_SHOWING or GB_SAVING. */
 
-  GbWidgetData	*widget_data;		/* The GbWidgetData of the widget
+  GladeWidgetData *widget_data;		/* The GladeWidgetData of the widget
 					   currently being processed. */
 
   /* These are only used when saving (to a file or the clipboard). */
@@ -291,7 +213,7 @@ typedef enum
 struct _GbWidgetSetArgData {
   GladeProject      *project;
   GbWidgetAction     action;		/* GB_APPLYING or GB_LOADING. */
-  GbWidgetData	    *widget_data;
+  GladeWidgetData   *widget_data;
   GtkWidget	    *property_to_apply;
   gboolean	     apply;
 
@@ -469,9 +391,11 @@ GtkWidget*  gb_widget_new_full		(const gchar	       *class_id,
 					 GbWidgetNewCallback	callback,
 					 GbWidgetAction		action,
 					 GbWidgetSetArgData    *loading_data);
-GbWidgetData* gb_widget_new_widget_data (GbWidget              *gbwidget);
 void	    gb_widget_create_from	(GtkWidget	       *widget,
 					 const gchar	       *name);
+void	    gb_widget_create_from_full	(GtkWidget		*widget,
+					 const gchar		*name,
+					 GladeWidgetData	*wdata);
 gboolean    gb_widget_can_finish_new	(GbWidgetNewData       *data);
 void        gb_widget_initialize	(GtkWidget	       *widget,
 					 GbWidgetNewData       *data);
@@ -581,6 +505,9 @@ void	    gb_widget_output_text	(GbWidgetGetArgData    *data,
 void	    gb_widget_output_translatable_text (GbWidgetGetArgData    *data,
 					 const gchar	       *property,
 					 const gchar	       *value);
+void	    gb_widget_output_translatable_text_in_lines (GbWidgetGetArgData *data,
+					 const gchar	       *property,
+					 const gchar	       *value);
 void	    gb_widget_output_int	(GbWidgetGetArgData    *data,
 					 const gchar	       *property,
 					 gint			value);
