@@ -289,6 +289,10 @@ gb_button_get_properties (GtkWidget * widget, GbWidgetGetArgData * data)
     {
       relief_visible = TRUE;
       gb_widget_output_child_label (widget, data, Label);
+
+      /* The Icon property is not applicable to normal buttons in GTK+. */
+      if (data->action == GB_SHOWING)
+	property_set_visible (Icon, FALSE);
     }
 #endif
 
@@ -497,7 +501,7 @@ gb_button_write_uline_accel_source (GtkWidget * widget,
   data->need_accel_group = TRUE;
   source_add (data,
 	      "  gtk_widget_add_accelerator (%s, \"clicked\", accel_group,\n"
-	      "                              %s_key, GDK_MOD1_MASK, 0);\n",
+	      "                              %s_key, GDK_MOD1_MASK, (GtkAccelFlags) 0);\n",
 	      data->wname, data->real_wname);
 }
 
@@ -779,7 +783,7 @@ gb_button_set_stock_button (GtkWidget *widget,
 	gtk_container_remove (GTK_CONTAINER (widget), GTK_BIN (widget)->child);
       gtk_container_add (GTK_CONTAINER (widget), child);
       gtk_widget_unref (child);
-      gtk_widget_destroy (new_button);
+      gtk_widget_unref (new_button);
     }
   else
     {
