@@ -301,7 +301,8 @@ gb_box_set_size (GtkWidget * widget, gint size)
       if (current_size > size)
 	{
 	  glade_util_show_message_box (error ? error
-				       : _("Can't delete any children."));
+				       : _("Can't delete any children."),
+				       widget);
 	}
     }
 }
