@@ -157,7 +157,7 @@ gb_option_menu_get_properties (GtkWidget * widget, GbWidgetGetArgData * data)
     }
   else
     {
-      gb_widget_output_translatable_text (data, Items, items);
+      gb_widget_output_translatable_text_in_lines (data, Items, items);
       gb_widget_output_int (data, Choice, add_label_data.selected_index);
       if (data->action == GB_SHOWING)
 	{
