@@ -100,8 +100,6 @@ gb_text_set_properties (GtkWidget * widget, GbWidgetSetArgData * data)
   text = gb_widget_input_text (data, Text);
   if (data->apply)
     {
-      /* Note: we need to realize the text before adding text or it SEGVs. */
-      gtk_widget_realize (widget);
       gtk_editable_delete_text (GTK_EDITABLE (widget), 0, -1);
       text = text ? text : "";
       gtk_text_insert (GTK_TEXT (widget), NULL, NULL, NULL, text, strlen (text));
@@ -156,11 +154,9 @@ gb_text_write_source (GtkWidget * widget, GbWidgetWriteSourceData * data)
     {
       gchar *text_output = source_make_string (text, data->use_gettext);
 
-      /* Note: we need to realize the text before adding text or it SEGVs. */
       /* Note: we use the length of the text rather than the result of
          souce_make_string() since the escaped characters will be converted
          back to the original string when compiled. */
-      source_add (data, "  gtk_widget_realize (%s);\n", data->wname);
       source_add (data,
 		  "  gtk_text_insert (GTK_TEXT (%s), NULL, NULL, NULL,\n"
 		  "                   %s, %i);\n",
