@@ -35,7 +35,34 @@ static GbWidget gbwidget;
 static gchar *Label = "ToggleButton|GtkButton::label";
 /* This is only used for toolbar buttons. */
 static gchar *Icon = "ToggleButton|GtkButton::icon";
+
+/* This is only used for normal buttons, not toolbar buttons. */
+static gchar *Relief = "ToggleButton|GtkButton::relief";
+
 static gchar *State = "GtkToggleButton::active";
+
+
+static const gchar *GbReliefChoices[] =
+{
+  "Normal",
+  "Half",
+  "None",
+  NULL
+};
+static const gint GbReliefValues[] =
+{
+  GTK_RELIEF_NORMAL,
+  GTK_RELIEF_HALF,
+  GTK_RELIEF_NONE
+};
+static const gchar *GbReliefSymbols[] =
+{
+  "GTK_RELIEF_NORMAL",
+  "GTK_RELIEF_HALF",
+  "GTK_RELIEF_NONE"
+};
+
+
 /* draw_indicator is not really useful for toggle buttons. I think its only
    for radio/check buttons. */
 /*static gchar *Indicator       = "GtkToggleButton::draw_indicator"; */
@@ -85,6 +112,9 @@ gb_toggle_button_create_properties (GtkWidget * widget, GbWidgetCreateArgData
 				    * data)
 {
   property_add_text (Label, _("Label:"), _("The text to display"), 2);
+  property_add_choice (Relief, _("Button Relief:"),
+		       _("The relief style of the button"),
+		       GbReliefChoices);
 #ifdef USE_GNOME
   gb_button_create_child_icon_property (widget, data, Icon);
 #else
@@ -104,7 +134,12 @@ gb_toggle_button_create_properties (GtkWidget * widget, GbWidgetCreateArgData
 static void
 gb_toggle_button_get_properties (GtkWidget * widget, GbWidgetGetArgData * data)
 {
-  if (gb_toolbar_is_toolbar_button (widget))
+  gboolean is_toolbar_button;
+  gint i;
+
+  is_toolbar_button = gb_toolbar_is_toolbar_button (widget);
+
+  if (is_toolbar_button)
     {
       gb_toolbar_output_child_label (widget, data, Label);
       gb_toolbar_output_child_icon (widget, data, Icon);
@@ -114,7 +149,22 @@ gb_toggle_button_get_properties (GtkWidget * widget, GbWidgetGetArgData * data)
       gb_widget_output_child_label (widget, data, Label);
     }
 
-  gb_widget_output_bool (data, State, data->widget_data->flags & GB_ACTIVE);
+  if (data->action == GB_SHOWING)
+    {
+      property_set_visible (Relief, !is_toolbar_button);
+      property_set_visible (Icon, is_toolbar_button);
+    }
+
+  if (!is_toolbar_button)
+    {
+      for (i = 0; i < sizeof (GbReliefValues) / sizeof (GbReliefValues[0]); i++)
+	{
+	  if (GbReliefValues[i] == GTK_BUTTON (widget)->relief)
+	    gb_widget_output_choice (data, Relief, i, GbReliefSymbols[i]);
+	}
+    }
+
+  gb_widget_output_bool (data, State, data->widget_data->flags & GLADE_ACTIVE);
 }
 
 
@@ -126,6 +176,9 @@ gb_toggle_button_get_properties (GtkWidget * widget, GbWidgetGetArgData * data)
 static void
 gb_toggle_button_set_properties (GtkWidget * widget, GbWidgetSetArgData * data)
 {
+  gboolean set_relief = FALSE;
+  gchar *relief;
+  gint i;
   gboolean state;
 
   if (gb_toolbar_is_toolbar_button (widget))
@@ -136,6 +189,26 @@ gb_toggle_button_set_properties (GtkWidget * widget, GbWidgetSetArgData * data)
   else
     {
       gb_widget_input_child_label (widget, data, Label);
+      set_relief = TRUE;
+    }
+
+  if (set_relief)
+    {
+      relief = gb_widget_input_choice (data, Relief);
+      if (data->apply)
+	{
+	  for (i = 0; i < sizeof (GbReliefValues) / sizeof (GbReliefValues[0]);
+	       i++)
+	    {
+	      if (!strcmp (relief, GbReliefChoices[i])
+		  || !strcmp (relief, GbReliefSymbols[i]))
+		{
+		  gtk_button_set_relief (GTK_BUTTON (widget),
+					 GbReliefValues[i]);
+		  break;
+		}
+	    }
+	}
     }
 
   state = gb_widget_input_bool (data, State);
@@ -143,9 +216,9 @@ gb_toggle_button_set_properties (GtkWidget * widget, GbWidgetSetArgData * data)
     {
       gtk_toggle_button_set_active (GTK_TOGGLE_BUTTON (widget), state);
       if (state)
-	data->widget_data->flags |= GB_ACTIVE;
+	data->widget_data->flags |= GLADE_ACTIVE;
       else
-	data->widget_data->flags &= ~GB_ACTIVE;
+	data->widget_data->flags &= ~GLADE_ACTIVE;
     }
 }
 
@@ -179,12 +252,15 @@ gb_toggle_button_write_source (GtkWidget * widget, GbWidgetWriteSourceData * dat
 {
   GtkWidget *child = GTK_BUTTON (widget)->child;
   gchar *label_text;
+  gboolean set_relief = TRUE;
+  gint i;
 
   if (data->create_widget)
     {
       if (gb_toolbar_is_toolbar_button (widget))
 	{
 	  gb_toolbar_write_toolbar_button_source (widget, data);
+	  set_relief = FALSE;
 	}
       else if (child && GTK_IS_LABEL (child) && !GB_IS_GB_WIDGET (child))
 	{
@@ -213,7 +289,19 @@ gb_toggle_button_write_source (GtkWidget * widget, GbWidgetWriteSourceData * dat
     }
   gb_widget_write_standard_source (widget, data);
 
-  if (data->widget_data->flags & GB_ACTIVE)
+  if (set_relief && GTK_BUTTON (widget)->relief != GTK_RELIEF_NORMAL)
+    {
+      for (i = 0; i < sizeof (GbReliefValues) / sizeof (GbReliefValues[0]);
+	   i++)
+	{
+	  if (GbReliefValues[i] == GTK_BUTTON (widget)->relief)
+	    source_add (data,
+			"  gtk_button_set_relief (GTK_BUTTON (%s), %s);\n",
+			data->wname, GbReliefSymbols[i]);
+	}
+    }
+
+  if (data->widget_data->flags & GLADE_ACTIVE)
     {
       source_add (data,
 	  "  gtk_toggle_button_set_active (GTK_TOGGLE_BUTTON (%s), TRUE);\n",
