@@ -154,7 +154,8 @@ static void gb_toolbar_set_stock_child_icon (GtkWidget *widget,
 static void gb_toolbar_set_child_icon (GtkWidget *widget,
 				       GbWidgetSetArgData * data,
 				       GtkWidget *icon,
-				       gchar *filename);
+				       gchar *filename,
+				       const gchar *property_name);
 static void gb_toolbar_reset_child_icon (GtkWidget *widget,
 					 GtkWidget *icon);
 static GtkWidget* gb_toolbar_get_toolbar_radio_group_widget (GtkWidget *widget,
@@ -1339,7 +1340,8 @@ gb_toolbar_input_child_icon (GtkWidget * widget,
       filename = gb_widget_input_pixmap_filename (data, property_name);
       if (data->apply)
 	{
-	  gb_toolbar_set_child_icon (widget, data, icon, filename);
+	  gb_toolbar_set_child_icon (widget, data, icon, filename,
+				     property_name);
 	}
       if (data->action == GB_LOADING)
 	g_free (filename);
@@ -1391,7 +1393,8 @@ gb_toolbar_set_stock_child_icon (GtkWidget *widget, GtkWidget *icon,
 
 static void
 gb_toolbar_set_child_icon (GtkWidget *widget, GbWidgetSetArgData * data,
-			   GtkWidget *icon, gchar *filename)
+			   GtkWidget *icon, gchar *filename,
+			   const gchar *property_name)
 {
   gchar *old_filename;
   GdkColormap *colormap;
@@ -1427,7 +1430,17 @@ gb_toolbar_set_child_icon (GtkWidget *widget, GbWidgetSetArgData * data,
 						       filename);
       if (!gdkpixmap)
 	{
-	  glade_util_show_message_box (_("Couldn't create pixmap from file\n"));
+	  if (data->action == GB_LOADING)
+	    {
+	      load_add_error_message_with_tag (data,
+					       GLADE_LINE_PROPERTY,
+					       _("Couldn't create pixmap from file"),
+					       property_name, filename);
+	    }
+	  else
+	    {
+	      glade_util_show_message_box (_("Couldn't create pixmap from file\n"), widget);
+	    }
 	}
       else
 	{
