@@ -148,6 +148,13 @@ glade_snap_to_grid (gboolean snap)
 }
 
 
+#if 0
+/* Changed editor_show_grid_settings_dialog and
+   editor_show_grid_settings_dialog to take a widget parameter, to use for
+   selecting a transient parent.
+   These functions don't know about any widgets. Since they're unused,
+   they're commented out. I guess it would be even better to remove them
+   outright. */
 void
 glade_show_grid_settings (void)
 {
@@ -160,6 +167,7 @@ glade_show_snap_settings (void)
 {
   editor_show_snap_settings_dialog ();
 }
+#endif
 
 
 gchar*
