@@ -25,8 +25,11 @@ extern "C" {
 #endif /* __cplusplus */
 
 
-GladePaletteSectionData* get_gnome_widgets(void);
+GladePaletteSectionData* get_gnome_widgets      (void);
 
+#ifdef ENABLE_BONOBO
+void                     gb_bonobo_control_init (void);
+#endif
 
 #ifdef __cplusplus
 }
