@@ -306,9 +306,9 @@ static GladeWidgetInitData notshown[] =
 
 static GladePaletteSectionData sections[] =
 {
-  { "GTK+ Basic", gtk_standard },
-  { "GTK+ Additional", gtk_advanced },
-  { "NotShown", notshown },
+  { N_("GTK+ Basic"), gtk_standard },
+  { N_("GTK+ Additional"), gtk_advanced },
+  { N_("NotShown"), notshown },
   { NULL, NULL }
 };
 
