@@ -133,8 +133,6 @@ glade_project_options_init (GladeProjectOptions * options)
   options->filesel = NULL;
   options->auto_generation_level = 0;
 
-  GTK_WINDOW (options)->type = GTK_WINDOW_DIALOG;
-
   tooltips = gtk_tooltips_new ();
 
   gtk_container_set_border_width (GTK_CONTAINER (options), 4);
@@ -1383,7 +1381,7 @@ glade_project_options_check_valid	(GladeProjectOptions *options)
 
   if (error)
     {
-      glade_util_show_message_box (error);
+      glade_util_show_message_box (error, GTK_WIDGET (options));
       return FALSE;
     }
 
