@@ -184,7 +184,10 @@ static GnomeUIInfo EditMenu[] =
   GNOMEUIINFO_MENU_CUT_ITEM (glade_project_window_cut, NULL),
   GNOMEUIINFO_MENU_COPY_ITEM (glade_project_window_copy, NULL),
   GNOMEUIINFO_MENU_PASTE_ITEM (glade_project_window_paste, NULL),
-  GNOMEUIINFO_MENU_CLEAR_ITEM (glade_project_window_delete, NULL),
+  { GNOME_APP_UI_ITEM, N_("_Delete"), N_("Delete the selected widget"),
+    glade_project_window_delete, NULL, NULL,
+    GNOME_APP_PIXMAP_STOCK, GNOME_STOCK_MENU_TRASH,
+    GDK_DELETE, 0, NULL },
   GNOMEUIINFO_END
 };
 
@@ -837,7 +840,7 @@ glade_project_window_new_project (GtkWidget *widget,
   project_window = get_glade_project_window (widget);
   g_return_if_fail (project_window != NULL);
 
-  dialog = glade_util_create_dialog_with_buttons (_("Are you sure you want to create a new project?"), 2, buttons, 2, handlers, project_window);
+  dialog = glade_util_create_dialog_with_buttons (_("Are you sure you want to create a new project?"), 2, buttons, 2, handlers, project_window, project_window->window);
   gtk_window_set_position (GTK_WINDOW (dialog), GTK_WIN_POS_MOUSE);
   gtk_window_set_wmclass (GTK_WINDOW (dialog), "new_project", "Glade");
   gtk_window_set_transient_for (GTK_WINDOW (dialog),
@@ -992,7 +995,7 @@ glade_project_window_new_errors_dialog (GladeProjectWindow *project_window,
 {
   GtkWidget *dialog, *vbox, *text, *hbbox, *ok_button, *scrolled_win;
 
-  dialog = gtk_window_new (GTK_WINDOW_DIALOG);
+  dialog = gtk_window_new (GTK_WINDOW_TOPLEVEL);
   gtk_window_set_position (GTK_WINDOW (dialog), GTK_WIN_POS_MOUSE);
   gtk_container_set_border_width (GTK_CONTAINER (dialog), 2);
 
@@ -1374,10 +1377,10 @@ static void
 glade_project_window_show_quit_dialog (GladeProjectWindow *project_window)
 {
   GtkWidget *dialog;
-  const gchar *buttons[] = { N_("Yes"), N_("No") };
+  const gchar *buttons[] = { N_("Quit"), N_("Cancel") };
   GtkSignalFunc handlers[] = { glade_project_window_on_quit_ok, NULL };
 
-  dialog = glade_util_create_dialog_with_buttons (_("Are you sure you want to quit?"), 2, buttons, 2, handlers, project_window);
+  dialog = glade_util_create_dialog_with_buttons (_("Are you sure you want to quit?"), 2, buttons, 2, handlers, project_window, project_window->window);
   gtk_window_set_position (GTK_WINDOW (dialog), GTK_WIN_POS_MOUSE);
   gtk_window_set_transient_for (GTK_WINDOW (dialog),
 				GTK_WINDOW (project_window->window));
@@ -1560,20 +1563,19 @@ static void
 glade_project_window_about (GtkWidget *widget,
 			    gpointer   data)
 {
-#ifdef USE_GNOME
-  const gchar *author[] = {"Damon Chaplin <glade@glade.pn.org>", NULL };
-  GtkWidget *about, *transient_parent;
-#else
-  gchar *message;
-#endif
-
   /* VERSION comes from configure.in - the only place it should be defined */
+
 #ifdef USE_GNOME
+  const gchar *author[] = { "Damon Chaplin <damon@ximian.com>",
+			    "Martijn van Beers <martijn@earthling.net>",
+			    NULL };
+  GtkWidget *about, *transient_parent, *hbox, *href;
+
   about = gnome_about_new (_("Glade"),
 			   VERSION,
-			   _("Copyright 1998 Damon Chaplin"),
+			   _("(C) 1998-2001 Damon Chaplin"),
 			   author,
-			   _("A GTK+ User Interface Builder\nWeb: http://glade.pn.org\n"),
+			   _("Glade is a User Interface Builder for GTK+ and GNOME.\n"),
 			   PACKAGE G_DIR_SEPARATOR_S "glade_logo.png");
   gtk_window_set_modal (GTK_WINDOW (about), TRUE);
   gtk_window_set_wmclass (GTK_WINDOW (about), "about", "Glade");
@@ -1581,16 +1583,32 @@ glade_project_window_about (GtkWidget *widget,
   if (GTK_IS_WINDOW (transient_parent))
     gtk_window_set_transient_for (GTK_WINDOW (about),
 				  GTK_WINDOW (transient_parent));
+
+  hbox = gtk_hbox_new (TRUE, 0);
+  href = gnome_href_new ("http://glade.pn.org/",
+			 _("Glade Home Page"));
+  gtk_box_pack_start (GTK_BOX (hbox), href, FALSE, FALSE, 0);
+  gtk_box_pack_start (GTK_BOX (GNOME_DIALOG (about)->vbox),
+		      hbox, TRUE, FALSE, 0);
+  gtk_widget_show_all (hbox);
+
   gtk_widget_show (about);
+
 #else
+  gchar *message;
+
   message = g_strdup_printf (_("G L A D E\n\n"
-			       "A GTK+ User Interface Builder\n\n"
-			       "Version %s\n\n"
-			       "By Damon Chaplin\n\n"
-			       "Email: glade@glade.pn.org\n"
-			       "Web: http://glade.pn.org\n"),
+			       "A User Interface Builder for GTK+ and GNOME\n\n"
+			       "Version %s\n"
+			       "\n"
+			       "By\n"
+			       "Damon Chaplin\n"
+			       "Martijn van Beers\n"
+			       "\n"
+			       "Email: damon@ximian.com\n"
+			       "Home Page: http://glade.pn.org\n"),
 			     VERSION);
-  glade_util_show_message_box (message);
+  glade_util_show_message_box (message, widget);
   g_free (message);
 #endif
 }
