@@ -46,19 +46,7 @@ static GbWidget gbwidget;
 static GtkWidget*
 gb_gnome_db_browser_new (GbWidgetNewData *data)
 {
-  GtkWidget *widget;
-  GnomeDbBrowser *brw;
-
-  widget = gnome_db_browser_new (NULL);
-  brw = GNOME_DB_BROWSER (widget);
-
-  /* Disconnect the toggle button signals, since they cause problems. */
-  gtk_signal_disconnect_by_data (GTK_OBJECT (brw->tables_button), brw);
-  gtk_signal_disconnect_by_data (GTK_OBJECT (brw->views_button), brw);
-  gtk_signal_disconnect_by_data (GTK_OBJECT (brw->procs_button), brw);
-  gtk_signal_disconnect_by_data (GTK_OBJECT (brw->types_button), brw);
-
-  return widget;
+  return gnome_db_browser_new (NULL);
 }
 
 
