@@ -18,7 +18,7 @@
 
 #include <config.h>
 
-#include <gda/gda-ui.h>
+#include <gnome-db.h>
 #include "../gb.h"
 
 /* Include the 21x21 icon pixmap for this widget, to be used in the palette */
