@@ -632,9 +632,11 @@ gb_gnome_dock_item_write_add_child_source (GtkWidget * parent,
 					   GtkWidget *child,
 					   GbWidgetWriteSourceData * data)
 {
+  GnomeApp *app;
+
   /* If we're adding a dock item to a GnomeApp's dock, we use
      the special functions to add it here. */
-  if (glade_gnome_is_app_dock_item (parent))
+  if ((app = glade_gnome_is_app_dock_item (parent)))
     {
       /* Children of floating items are added as normal. */
       if (GNOME_DOCK_ITEM (parent)->is_floating)
@@ -647,6 +649,17 @@ gb_gnome_dock_item_write_add_child_source (GtkWidget * parent,
 	  source_add (data,
 		      "  gnome_app_create_menus (GNOME_APP (%s), %s_uiinfo);\n",
 		      data->component_name, data->real_wname);
+
+	  /* Output the code to install the menu hints, if the GnomeApp has
+	     a status bar. This must be output after the code to create the
+	     GnomeAppBar is output, so we add it to the same buffer as the
+	     signal connections. */
+	  if (app->statusbar)
+	    {
+	      source_add_to_buffer (data, GLADE_SIGNAL_CONNECTIONS,
+				    "  gnome_app_install_menu_hints (GNOME_APP (%s), %s_uiinfo);\n",
+				    data->component_name, data->real_wname);
+	    }
 	}
       else
 	{
