@@ -67,48 +67,28 @@ GladeStatusCode
 load_project_file (GladeProject *project,
 		   GList       **errors)
 {
-  gchar *old_locale, *saved_locale, *saved_timezone;
+  gchar *saved_locale, *saved_timezone;
   GladeStatusCode status;
-     
+
   *errors = NULL;
 
-  old_locale = setlocale (LC_NUMERIC, NULL);
-  saved_locale = g_strdup (old_locale);
+  /* Set the locale to "C". */
+  saved_locale = g_strdup (setlocale (LC_NUMERIC, NULL));
   setlocale (LC_NUMERIC, "C");
 
-  /* Save the current time zone environment variable. */
-  saved_timezone = g_strdup (getenv ("TZ"));
-  if (putenv ("TZ=GMT") == -1)
-    {
-      status = GLADE_STATUS_ERROR;
-      *errors = g_list_append (*errors,
-			       g_strdup (_("Couldn't set time zone.\n")));
-    }
-  else
-    status = real_load_project_file (project, errors);
+  /* Set the timezone to "UTC". */
+  saved_timezone = glade_util_set_timezone ("UTC");
 
-  /* Now reset the timezone. */
-  if (saved_timezone)
-    {
-      gchar *new_timezone = g_strdup_printf ("TZ=%s", saved_timezone);
-      putenv (new_timezone);
-      g_free (new_timezone);
-      g_free (saved_timezone);
-    }
-  else
-    {
-#ifdef HAVE_SETENV
-      unsetenv ("TZ");
-#else
-      /* This doesn't work on my system. We need to reset TZ here. The only
-	 other way I can think of doing this is by changing environ.
-	 Note that this code is needed in load.c & glade_clipboard.c */
-      putenv ("TZ=");
-#endif
-    }
+  /* Now save the project XML file. */
+  status = real_load_project_file (project, errors);
 
+  /* Reset the timezone. */
+  glade_util_reset_timezone (saved_timezone);
+
+  /* Reset the locale. */
   setlocale (LC_NUMERIC, saved_locale);
   g_free (saved_locale);
+
   return status;
 }
 
@@ -577,13 +557,12 @@ load_add_error_message (GbWidgetSetArgData * data,
 			const gchar *message,
 			const gchar *value)
 {
-  gchar buffer[1024], *error_message;
+  gchar *error_message;
 
-  sprintf (buffer, _("Line %i - %s %s %s\n"),
-	   line_number, message, value ? ":" : "", value ? value : "");
+  error_message = g_strdup_printf (_("Line %i - %s %s %s\n"),
+				   line_number, message,
+				   value ? ":" : "", value ? value : "");
 
-  error_message = g_new (gchar, strlen (buffer) + 1);
-  strcpy (error_message, buffer);
   data->error_messages = g_list_append (data->error_messages, error_message);
 }
 
@@ -595,7 +574,7 @@ load_add_error_message_with_tag (GbWidgetSetArgData * data,
 				 const gchar * tag_name,
 				 const gchar * value)
 {
-  gchar buffer[1024], *error_message, *real_tag_name;
+  gchar *error_message, *real_tag_name;
   gint line_number;
 
   real_tag_name = glade_util_find_start_of_tag_name (tag_name);
@@ -605,11 +584,10 @@ load_add_error_message_with_tag (GbWidgetSetArgData * data,
   else
     line_number = data->line_number;
 
-  sprintf (buffer, _("Line %i - %s:\n  %s = %s\n"),
-	   line_number, message, real_tag_name, value ? value : "");
+  error_message = g_strdup_printf (_("Line %i - %s:\n  %s = %s\n"),
+				   line_number, message,
+				   real_tag_name, value ? value : "");
 
-  error_message = g_new (gchar, strlen (buffer) + 1);
-  strcpy (error_message, buffer);
   data->error_messages = g_list_append (data->error_messages, error_message);
 }
 
