@@ -105,6 +105,9 @@ static void source_write_gnome_macro_files (GbWidgetWriteSourceData * data);
 
 static void source_write_common_build_files (GbWidgetWriteSourceData * data);
 static void source_write_toplevel_makefile_am (GbWidgetWriteSourceData * data);
+static void source_write_extra_dist (GbWidgetWriteSourceData * data,
+				     const gchar *directory,
+				     FILE *fp);
 static GladeError* source_create_file_if_not_exist (const gchar *directory,
 						    const gchar *filename,
 						    const gchar *contents);
@@ -1112,6 +1115,7 @@ source_write_gtk_makefile_am (GbWidgetWriteSourceData * data)
 {
   FILE *fp;
   gchar *directory, *source_directory, *filename, *program_name_as_target;
+  gboolean is_toplevel;
 
   directory = glade_project_get_directory (data->project);
   source_directory = glade_project_get_source_directory (data->project);
@@ -1139,7 +1143,9 @@ source_write_gtk_makefile_am (GbWidgetWriteSourceData * data)
 
   /* If the project directory is the source directory, we need to output
      SUBDIRS here. */
-  if (glade_util_directories_equivalent (directory, source_directory))
+  is_toplevel = glade_util_directories_equivalent (directory,
+						   source_directory);
+  if (is_toplevel)
     {
       fprintf (fp, "SUBDIRS =");
 
@@ -1164,7 +1170,7 @@ source_write_gtk_makefile_am (GbWidgetWriteSourceData * data)
   fprintf (fp,
 	   "bin_PROGRAMS = %s\n"
 	   "\n",
-	   program_name_as_target);
+	   data->program_name);
 
   fprintf (fp,
 	   "%s_SOURCES = \\\n",
@@ -1197,6 +1203,9 @@ source_write_gtk_makefile_am (GbWidgetWriteSourceData * data)
     }
   fprintf (fp, "\n\n");
 
+  if (is_toplevel)
+    source_write_extra_dist (data, source_directory, fp);
+
   source_write_gtk_makefile_am_pixmaps_targets (data, source_directory, fp);
 
   fclose (fp);
@@ -1413,14 +1422,6 @@ source_write_gnome_configure_in (GbWidgetWriteSourceData * data)
 	       "\n");
     }
 
-  /* Subst PACKAGE_PIXMAPS_DIR so the Makefile.am knows where to install the
-     pixmaps. */
-  fprintf (fp,
-	   "dnl Subst PACKAGE_PIXMAPS_DIR.\n"
-	   "PACKAGE_PIXMAPS_DIR=\"`gnome-config --datadir`/pixmaps/${PACKAGE}\"\n"
-	   "AC_SUBST(PACKAGE_PIXMAPS_DIR)\n"
-	   "\n");
-
   /* GnomeDB support. */
   if (glade_project_get_gnome_db_support (data->project))
     {
@@ -1468,6 +1469,7 @@ source_write_gnome_makefile_am (GbWidgetWriteSourceData * data)
 {
   FILE *fp;
   gchar *directory, *source_directory, *filename, *program_name_as_target;
+  gboolean is_toplevel;
 
   directory = glade_project_get_directory (data->project);
   source_directory = glade_project_get_source_directory (data->project);
@@ -1495,7 +1497,9 @@ source_write_gnome_makefile_am (GbWidgetWriteSourceData * data)
 
   /* If the project directory is the source directory, we need to output
      SUBDIRS here. */
-  if (glade_util_directories_equivalent (directory, source_directory))
+  is_toplevel = glade_util_directories_equivalent (directory,
+						   source_directory);
+  if (is_toplevel)
     {
       fprintf (fp, "SUBDIRS =");
 
@@ -1520,7 +1524,7 @@ source_write_gnome_makefile_am (GbWidgetWriteSourceData * data)
   fprintf (fp,
 	   "bin_PROGRAMS = %s\n"
 	   "\n",
-	   program_name_as_target);
+	   data->program_name);
 
   fprintf (fp,
 	   "%s_SOURCES = \\\n",
@@ -1553,6 +1557,9 @@ source_write_gnome_makefile_am (GbWidgetWriteSourceData * data)
     }
   fprintf (fp, "\n\n");
 
+  if (is_toplevel)
+    source_write_extra_dist (data, source_directory, fp);
+
   source_write_gnome_makefile_am_pixmaps_targets (data, source_directory, fp);
 
   fclose (fp);
@@ -1589,10 +1596,10 @@ source_write_gnome_makefile_am_pixmaps_targets (GbWidgetWriteSourceData * data,
 	   "install-data-local:\n"
 	   "\t@$(NORMAL_INSTALL)\n"
 	   "\tif test -d $(srcdir)/%s; then \\\n"
-	   "\t  $(mkinstalldirs) $(DESTDIR)@PACKAGE_PIXMAPS_DIR@; \\\n"
+	   "\t  $(mkinstalldirs) $(DESTDIR)$(datadir)/pixmaps/$(PACKAGE); \\\n"
 	   "\t  for pixmap in $(srcdir)/%s/*; do \\\n"
 	   "\t    if test -f $$pixmap; then \\\n"
-	   "\t      $(INSTALL_DATA) $$pixmap $(DESTDIR)@PACKAGE_PIXMAPS_DIR@; \\\n"
+	   "\t      $(INSTALL_DATA) $$pixmap $(DESTDIR)$(datadir)/pixmaps/$(PACKAGE); \\\n"
 	   "\t    fi \\\n"
 	   "\t  done \\\n"
 	   "\tfi\n"
@@ -1784,6 +1791,8 @@ source_write_toplevel_makefile_am (GbWidgetWriteSourceData * data)
 
   fprintf (fp, " %s\n\n", source_subdir);
 
+  source_write_extra_dist (data, directory, fp);
+
   if (glade_project_get_gnome_support (data->project))
     source_write_gnome_makefile_am_pixmaps_targets (data, directory, fp);
   else
@@ -1796,6 +1805,27 @@ source_write_toplevel_makefile_am (GbWidgetWriteSourceData * data)
 }
 
 
+static void
+source_write_extra_dist (GbWidgetWriteSourceData * data,
+			 const gchar *directory,
+			 FILE *fp)
+{
+  gchar *xml_filename;
+
+  xml_filename = glade_project_get_xml_filename (data->project);
+
+  xml_filename = glade_util_make_relative_path (directory, xml_filename);
+
+  fprintf (fp,
+	   "EXTRA_DIST = \\\n"
+	   "\tautogen.sh \\\n"
+	   "\t%s\n\n",
+	   xml_filename);
+
+  g_free (xml_filename);
+}
+
+
 /* This creates an empty file in the given directory if it doesn't already
    exist. It is used to create the empty NEWS, README, AUTHORS & ChangeLog. */
 static GladeError*
@@ -2834,6 +2864,9 @@ source_backup_file_if_exists (const gchar * filename)
   if (glade_util_file_exists (filename))
     {
       backup_filename = g_strdup_printf ("%s.bak", filename);
+#if defined (__EMX__) || defined (_WIN32)
+      remove (backup_filename);
+#endif
       status = rename (filename, backup_filename);
 
       if (status == -1)
