@@ -64,17 +64,13 @@ static void tree_move_to_parent	(GtkWidget	*widget,
 
 /* public functions */
 
-/* This creates the widget tree window, with just the root tree.
-
-   FIXME: It is a dialog, but transient for nobody - this means it can't be
-   iconized. Either make it toplevel, or make it transient for the project
-   window. */
+/* This creates the widget tree window, with just the root tree. */
 void
 tree_init ()
 {
   GtkWidget *scrolled_win;
 
-  win_tree = gtk_window_new (GTK_WINDOW_DIALOG);
+  win_tree = gtk_window_new (GTK_WINDOW_TOPLEVEL);
   gtk_widget_set_uposition (win_tree, 510, 0);
   gtk_widget_set_name (win_tree, "GladeWidgetTree");
   gtk_signal_connect (GTK_OBJECT (win_tree), "delete_event",
