@@ -1280,11 +1280,20 @@ gint
 glade_util_close_window (GtkWidget * widget)
 {
   gint x, y;
+  gboolean set_position = FALSE;
 
   /* remember position of window for when it is used again */
-  gdk_window_get_root_origin (widget->window, &x, &y);
+  if (widget->window)
+    {
+      gdk_window_get_root_origin (widget->window, &x, &y);
+      set_position = TRUE;
+    }
+
   gtk_widget_hide (widget);
-  gtk_widget_set_uposition (widget, x, y);
+
+  if (set_position)
+    gtk_widget_set_uposition (widget, x, y);
+
   return TRUE;
 }
 
